@@ -1,6 +1,6 @@
 # Process [link](<to> "stuff")
 
-from ..common.utils import normalizeReference, isSpace, charCodeAt
+from ..common.utils import normalizeReference, isSpace
 from ..common.normalize_url import normalizeLink, validateLink
 from .state_inline import StateInline
 
@@ -14,7 +14,7 @@ def link(state: StateInline, silent: bool):
     start = state.pos
     parseReference = True
 
-    if charCodeAt(state.src, state.pos) != 0x5B:  # /* [ */
+    if state.srcCharCode[state.pos] != 0x5B:  # /* [ */
         return False
 
     labelStart = state.pos + 1
@@ -26,7 +26,7 @@ def link(state: StateInline, silent: bool):
 
     pos = labelEnd + 1
 
-    if pos < maximum and charCodeAt(state.src, pos) == 0x28:  # /* ( */
+    if pos < maximum and state.srcCharCode[pos] == 0x28:  # /* ( */
         #
         # Inline link
         #
@@ -38,7 +38,7 @@ def link(state: StateInline, silent: bool):
         #        ^^ skipping these spaces
         pos += 1
         while pos < maximum:
-            code = charCodeAt(state.src, pos)
+            code = state.srcCharCode[pos]
             if not isSpace(code) and code != 0x0A:
                 break
             pos += 1
@@ -61,7 +61,7 @@ def link(state: StateInline, silent: bool):
         #                ^^ skipping these spaces
         start = pos
         while pos < maximum:
-            code = charCodeAt(state.src, pos)
+            code = state.srcCharCode[pos]
             if not isSpace(code) and code != 0x0A:
                 break
             pos += 1
@@ -76,14 +76,14 @@ def link(state: StateInline, silent: bool):
             # [link](  <href>  "title"  )
             #                         ^^ skipping these spaces
             while pos < maximum:
-                code = charCodeAt(state.src, pos)
+                code = state.srcCharCode[pos]
                 if not isSpace(code) and code != 0x0A:
                     break
                 pos += 1
         else:
             title = ""
 
-        if pos >= maximum or charCodeAt(state.src, pos) != 0x29:  # /* ) */
+        if pos >= maximum or state.srcCharCode[pos] != 0x29:  # /* ) */
             # parsing a valid shortcut link failed, fallback to reference
             parseReference = True
 
@@ -96,7 +96,7 @@ def link(state: StateInline, silent: bool):
         if "references" not in state.env:
             return False
 
-        if pos < maximum and charCodeAt(state.src, pos) == 0x5B:  # /* [ */
+        if pos < maximum and state.srcCharCode[pos] == 0x5B:  # /* [ */
             start = pos + 1
             pos = state.md.helpers.parseLinkLabel(state, pos)
             if pos >= 0:
